@@ -488,6 +488,30 @@ enum css_padding_e {
 	CSS_PADDING_SET				= 0x1
 };
 
+enum css_page_break_after_e {
+	CSS_PAGE_BREAK_AFTER_INHERIT		= 0x0,
+	CSS_PAGE_BREAK_AFTER_AUTO		= 0x1,
+	CSS_PAGE_BREAK_AFTER_AVOID		= 0x2,
+	CSS_PAGE_BREAK_AFTER_ALWAYS		= 0x3,
+	CSS_PAGE_BREAK_AFTER_LEFT		= 0x4,
+	CSS_PAGE_BREAK_AFTER_RIGHT		= 0x5
+};	
+	
+enum css_page_break_before_e {
+	CSS_PAGE_BREAK_BEFORE_INHERIT		= CSS_PAGE_BREAK_AFTER_INHERIT,
+	CSS_PAGE_BREAK_BEFORE_AUTO		= CSS_PAGE_BREAK_AFTER_AUTO,
+	CSS_PAGE_BREAK_BEFORE_AVOID		= CSS_PAGE_BREAK_AFTER_AVOID,
+	CSS_PAGE_BREAK_BEFORE_ALWAYS		= CSS_PAGE_BREAK_AFTER_ALWAYS,
+	CSS_PAGE_BREAK_BEFORE_LEFT		= CSS_PAGE_BREAK_AFTER_LEFT,
+	CSS_PAGE_BREAK_BEFORE_RIGHT		= CSS_PAGE_BREAK_AFTER_RIGHT
+};
+
+enum css_page_break_inside_e {
+	CSS_PAGE_BREAK_INSIDE_INHERIT		= CSS_PAGE_BREAK_AFTER_INHERIT,
+	CSS_PAGE_BREAK_INSIDE_AUTO		= CSS_PAGE_BREAK_AFTER_AUTO,
+	CSS_PAGE_BREAK_INSIDE_AVOID		= CSS_PAGE_BREAK_AFTER_AVOID
+};
+
 enum css_position_e {
 	CSS_POSITION_INHERIT			= 0x0,
 	CSS_POSITION_STATIC			= 0x1,
